@@ -1,7 +1,6 @@
 /* This is a generated file. See swfdec_as_strings.c for details. */
 #ifndef _SWFDEC_AS_STRINGS_H_
 #define _SWFDEC_AS_STRINGS_H_
-G_BEGIN_DECLS
 extern const char swfdec_as_strings[];
 #define SWFDEC_AS_STR_EMPTY &swfdec_as_strings[1]
 #define SWFDEC_AS_STR___proto__ &swfdec_as_strings[3]
@@ -471,6 +470,4 @@ extern const char swfdec_as_strings[];
 #define SWFDEC_AS_STR_height &swfdec_as_strings[4903]
 #define SWFDEC_AS_STR_deblocking &swfdec_as_strings[4911]
 #define SWFDEC_AS_STR_smoothing &swfdec_as_strings[4923]
-#define SWFDEC_AS_STR_Invalid_Date &swfdec_as_strings[4934]
-G_END_DECLS
 #endif
